package de.intevation.gnv.artifacts.context;

import de.intevation.artifactdatabase.DefaultArtifactContext;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Paint;

import java.io.File;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

/**
 * This class defines some final fields used to store some meta information
 * required during the  work with an artifact into a context object which is
 * available in each request specified in
 * <code>de.intevation.gnv.artifacts.Artifacts</code> and further methods called
 * by those.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class GNVArtifactContext
extends      DefaultArtifactContext
{
    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(GNVArtifactContext.class);

    public static final String CHART_TEMPLATE_KEY =
        "gnv.chart.template";

    public static final String HORIZONTAL_CROSS_SECTION_PROFILE_SAMPLES_KEY =
        "gnv.horizontal.cross.section.profile.samples";

    public static final String HORIZONTAL_CROSS_SECTION_SAMPLES_KEY =
        "gnv.horizontal.cross.section.samples";

    public static final String HORIZONTAL_CROSS_SECTION_EXTRAPOLATION_ROUNDS_KEY =
        "gnv.horizontal.cross.section.extrapolation.rounds";

    public static final String
        HORIZONTAL_CROSS_SECTION_RESULT_SHAPEFILE_PATH_KEY =
        "gnv.horizontal.cross.section.result.shapefile";

    public static final File
        DEFAULT_HORIZONTAL_CROSS_SECTION_PROFILE_SHAPEFILE_PATH =
        new File(System.getProperty("java.io.tmpdir"));

    public static final Integer
        DEFAULT_HORIZONTAL_CROSS_SECTION_PROFILE_SAMPLES = Integer.valueOf(250);

    public static final Integer
        DEFAULT_HORIZONTAL_CROSS_SECTION_SAMPLES = Integer.valueOf(1024);

    public static final Integer
        DEFAULT_HORIZONTAL_CROSS_SECTION_EXTRAPOLATION_ROUNDS = Integer.valueOf(0);

    public static final String HORIZONTAL_CROSS_SECTION_GROUND_INTERPOLATION_KEY =
        "gnv.horizontal.cross.section.ground.interpolation";

    public static final String DEFAULT_HORIZONTAL_CROSS_SECTION_GROUND_INTERPOLATION =
        "bilinear";

    public static final String PALETTES_KEY =
        "gnv.color.palettes";

    public static final String VERTICAL_CROSS_SECTION_SAMPLES_KEY =
        "gnv.vertical.cross.section.samples";

    public static final Dimension DEFAULT_VERTICAL_CROSS_SECTION_SAMPLES =
        new Dimension(1024, 768);

    public static final String VERTICAL_CROSS_SECTION_FILTER_FACTORIES_KEY =
        "gnv.vertical.cross.section.filter.factories";

    public static final String VERTICAL_CROSS_SECTION_GROUND_INTERPOLATION_KEY =
        "gnv.vertical.cross.section.ground.interpolation";

    public static final String DEFAULT_VERTICAL_CROSS_SECTION_GROUND_INTERPOLATION =
        "bilinear";

    public static final String VERTICAL_CROSS_SECTION_GROUND_FILL_KEY =
        "gnv.vertical.cross.section.ground.fill";

    public static final String MAPSERVER_SERVER_PATH_KEY =
        "mapserver.server.path";

    public static final String MAPSERVER_MAP_PATH_KEY =
        "mapserver.map.path";

    public static final Paint DEFAULT_VERTICAL_CROSS_SECTION_GROUND_FILL =
        new Color(0x7c8683);

    public GNVArtifactContext() {
        super();
        log.debug("GNVArtifactContext.Constructor");
    }

    public GNVArtifactContext(Document config) {
        super(config);
        log.debug("GNVArtifactContext.Constructor(config)");
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
